@@ -159,9 +159,9 @@ class JointPose:
     """关节位置，关节旋转角度描述的机器人姿态"""
 
     def __init__(self, *j):
-        if hasattr(j[0], 'pos'):
+        if len(j) > 0 and hasattr(j[0], 'pos'):
             self.pos = list(j[0].pos)
-        elif hasattr(j[0], '__iter__'):
+        elif len(j) > 0 and hasattr(j[0], '__iter__'):
             self.pos = list(j[0])
         else:
             self.pos = list(j)
@@ -222,19 +222,18 @@ class TaskInfo:
     """更新时间"""
 
     def __init__(self, res):
-        self.id = getattr(res, "id")
-        self.scene_id = getattr(res, "scene_id")
-        self.execute_count = getattr(res, "execute_count")
-        self.executed_count = getattr(res, "executed_count")
-        self.name = getattr(res, "name")
-        self.status = TaskStatus(getattr(res, "status"))
-        self.comment = getattr(res, "comment")
-        self.start_time = getattr(res, "start_time")
-        self.end_time = getattr(res, "end_time")
-        self.consume_time = getattr(res, "consume_time")
-        self.create_time = getattr(res, "create_time")
-        self.update_time = getattr(res, "update_time")
-
+        self.id = res.get("id")
+        self.scene_id = res.get("scene_id")
+        self.execute_count = res.get("execute_count")
+        self.executed_count = res.get("executed_count")
+        self.name = res.get("name")
+        self.status = TaskStatus(res.get("status"))
+        self.comment = res.get("comment")
+        self.start_time = res.get("start_time")
+        self.end_time = res.get("end_time")
+        self.consume_time = res.get("consume_time")
+        self.create_time = res.get("create_time")
+        self.update_time = res.get("update_time")
 
 class TasksResult:
     """
@@ -348,7 +347,9 @@ class RobotData(RobotPoseData):
 
 class IOItem:
     pin: int
+    """针脚"""
     value: float
+    """值"""
 
     def __init__(self, pin: int, value: float):
         self.pin = pin
